==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/outputs/VirtualMachineNetworkInterfaceIPConfigurationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Describes a virtual machine network profile's IP configuration.
 * @property applicationGatewayBackendAddressPools Specifies an array of references to backend address pools of application gateways. A virtual machine can reference backend address pools of multiple application gateways. Multiple virtual machines cannot use the same application gateway.
 * @property applicationSecurityGroups Specifies an array of references to application security group.
 * @property loadBalancerBackendAddressPools Specifies an array of references to backend address pools of load balancers. A virtual machine can reference backend address pools of one public and one internal load balancer. [Multiple virtual machines cannot use the same basic sku load balancer].
 * @property name The IP configuration name.
 * @property primary Specifies the primary network interface in case the virtual machine has more than 1 network interface.
 * @property privateIPAddressVersion Available from Api-Version 2017-03-30 onwards, it represents whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.  Possible values are: 'IPv4' and 'IPv6'.
 * @property publicIPAddressConfiguration The publicIPAddressConfiguration.
 * @property subnet Specifies the identifier of the subnet.
 */
public data class VirtualMachineNetworkInterfaceIPConfigurationResponse(
    public val applicationGatewayBackendAddressPools: List<SubResourceResponse>? = null,
    public val applicationSecurityGroups: List<SubResourceResponse>? = null,
    public val loadBalancerBackendAddressPools: List<SubResourceResponse>? = null,
    public val name: String,
    public val primary: Boolean? = null,
    public val privateIPAddressVersion: String? = null,
    public val publicIPAddressConfiguration: VirtualMachinePublicIPAddressConfigurationResponse? =
        null,
    public val subnet: SubResourceResponse? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.compute.outputs.VirtualMachineNetworkInterfaceIPConfigurationResponse):
            VirtualMachineNetworkInterfaceIPConfigurationResponse =
            VirtualMachineNetworkInterfaceIPConfigurationResponse(
                applicationGatewayBackendAddressPools = javaType.applicationGatewayBackendAddressPools().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }),
                applicationSecurityGroups = javaType.applicationSecurityGroups().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }),
                loadBalancerBackendAddressPools = javaType.loadBalancerBackendAddressPools().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }),
                name = javaType.name(),
                primary = javaType.primary().map({ args0 -> args0 }).orElse(null),
                privateIPAddressVersion = javaType.privateIPAddressVersion().map({ args0 -> args0 }).orElse(null),
                publicIPAddressConfiguration = javaType.publicIPAddressConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachinePublicIPAddressConfigurationResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                subnet = javaType.subnet().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/compute/kotlin/outputs/VirtualMachineNetworkInterfaceIPConfigurationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Describes a virtual machine network profile's IP configuration.
 * @property applicationGatewayBackendAddressPools Specifies an array of references to backend address pools of application gateways. A virtual machine can reference backend address pools of multiple application gateways. Multiple virtual machines cannot use the same application gateway.
 * @property applicationSecurityGroups Specifies an array of references to application security group.
 * @property loadBalancerBackendAddressPools Specifies an array of references to backend address pools of load balancers. A virtual machine can reference backend address pools of one public and one internal load balancer. [Multiple virtual machines cannot use the same basic sku load balancer].
 * @property name The IP configuration name.
 * @property primary Specifies the primary network interface in case the virtual machine has more than 1 network interface.
 * @property privateIPAddressVersion Available from Api-Version 2017-03-30 onwards, it represents whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.  Possible values are: 'IPv4' and 'IPv6'.
 * @property publicIPAddressConfiguration The publicIPAddressConfiguration.
 * @property subnet Specifies the identifier of the subnet.
 */
public data class VirtualMachineNetworkInterfaceIPConfigurationResponse(
    public val applicationGatewayBackendAddressPools: List<SubResourceResponse>? = null,
    public val applicationSecurityGroups: List<SubResourceResponse>? = null,
    public val loadBalancerBackendAddressPools: List<SubResourceResponse>? = null,
    public val name: String,
    public val primary: Boolean? = null,
    public val privateIPAddressVersion: String? = null,
    public val publicIPAddressConfiguration: VirtualMachinePublicIPAddressConfigurationResponse? =
        null,
    public val subnet: SubResourceResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.compute.outputs.VirtualMachineNetworkInterfaceIPConfigurationResponse): VirtualMachineNetworkInterfaceIPConfigurationResponse =
            VirtualMachineNetworkInterfaceIPConfigurationResponse(
                applicationGatewayBackendAddressPools = javaType.applicationGatewayBackendAddressPools().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }),
                applicationSecurityGroups = javaType.applicationSecurityGroups().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }),
                loadBalancerBackendAddressPools = javaType.loadBalancerBackendAddressPools().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }),
                name = javaType.name(),
                primary = javaType.primary().map({ args0 -> args0 }).orElse(null),
                privateIPAddressVersion = javaType.privateIPAddressVersion().map({ args0 -> args0 }).orElse(null),
                publicIPAddressConfiguration = javaType.publicIPAddressConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachinePublicIPAddressConfigurationResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                subnet = javaType.subnet().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
